==> openshift-model-operator-6.13.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftSDNConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OpenShiftSDNConfigFluent<A extends OpenShiftSDNConfigFluent<A>> extends BaseFluent<A>{
  public OpenShiftSDNConfigFluent() {
  }
  
  public OpenShiftSDNConfigFluent(OpenShiftSDNConfig instance) {
    this.copyInstance(instance);
  }
  private Boolean enableUnidling;
  private String mode;
  private Integer mtu;
  private Boolean useExternalOpenvswitch;
  private Integer vxlanPort;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OpenShiftSDNConfig instance) {
    instance = (instance != null ? instance : new OpenShiftSDNConfig());
    if (instance != null) {
          this.withEnableUnidling(instance.getEnableUnidling());
          this.withMode(instance.getMode());
          this.withMtu(instance.getMtu());
          this.withUseExternalOpenvswitch(instance.getUseExternalOpenvswitch());
          this.withVxlanPort(instance.getVxlanPort());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getEnableUnidling() {
    return this.enableUnidling;
  }
  
  public A withEnableUnidling(Boolean enableUnidling) {
    this.enableUnidling = enableUnidling;
    return (A) this;
  }
  
  public boolean hasEnableUnidling() {
    return this.enableUnidling != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode = mode;
    return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public Integer getMtu() {
    return this.mtu;
  }
  
  public A withMtu(Integer mtu) {
    this.mtu = mtu;
    return (A) this;
  }
  
  public boolean hasMtu() {
    return this.mtu != null;
  }
  
  public Boolean getUseExternalOpenvswitch() {
    return this.useExternalOpenvswitch;
  }
  
  public A withUseExternalOpenvswitch(Boolean useExternalOpenvswitch) {
    this.useExternalOpenvswitch = useExternalOpenvswitch;
    return (A) this;
  }
  
  public boolean hasUseExternalOpenvswitch() {
    return this.useExternalOpenvswitch != null;
  }
  
  public Integer getVxlanPort() {
    return this.vxlanPort;
  }
  
  public A withVxlanPort(Integer vxlanPort) {
    this.vxlanPort = vxlanPort;
    return (A) this;
  }
  
  public boolean hasVxlanPort() {
    return this.vxlanPort != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftSDNConfigFluent that = (OpenShiftSDNConfigFluent) o;
    if (!java.util.Objects.equals(enableUnidling, that.enableUnidling)) return false;
    if (!java.util.Objects.equals(mode, that.mode)) return false;
    if (!java.util.Objects.equals(mtu, that.mtu)) return false;
    if (!java.util.Objects.equals(useExternalOpenvswitch, that.useExternalOpenvswitch)) return false;
    if (!java.util.Objects.equals(vxlanPort, that.vxlanPort)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(enableUnidling,  mode,  mtu,  useExternalOpenvswitch,  vxlanPort,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enableUnidling != null) { sb.append("enableUnidling:"); sb.append(enableUnidling + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (mtu != null) { sb.append("mtu:"); sb.append(mtu + ","); }
    if (useExternalOpenvswitch != null) { sb.append("useExternalOpenvswitch:"); sb.append(useExternalOpenvswitch + ","); }
    if (vxlanPort != null) { sb.append("vxlanPort:"); sb.append(vxlanPort + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withEnableUnidling() {
    return withEnableUnidling(true);
  }
  
  public A withUseExternalOpenvswitch() {
    return withUseExternalOpenvswitch(true);
  }
  

}

==> openshift-model-operator-7.1.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftSDNConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OpenShiftSDNConfigFluent<A extends OpenShiftSDNConfigFluent<A>> extends BaseFluent<A>{
  public OpenShiftSDNConfigFluent() {
  }
  
  public OpenShiftSDNConfigFluent(OpenShiftSDNConfig instance) {
    this.copyInstance(instance);
  }
  private Boolean enableUnidling;
  private String mode;
  private Long mtu;
  private Boolean useExternalOpenvswitch;
  private Long vxlanPort;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OpenShiftSDNConfig instance) {
    instance = (instance != null ? instance : new OpenShiftSDNConfig());
    if (instance != null) {
          this.withEnableUnidling(instance.getEnableUnidling());
          this.withMode(instance.getMode());
          this.withMtu(instance.getMtu());
          this.withUseExternalOpenvswitch(instance.getUseExternalOpenvswitch());
          this.withVxlanPort(instance.getVxlanPort());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getEnableUnidling() {
    return this.enableUnidling;
  }
  
  public A withEnableUnidling(Boolean enableUnidling) {
    this.enableUnidling = enableUnidling;
    return (A) this;
  }
  
  public boolean hasEnableUnidling() {
    return this.enableUnidling != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode = mode;
    return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public Long getMtu() {
    return this.mtu;
  }
  
  public A withMtu(Long mtu) {
    this.mtu = mtu;
    return (A) this;
  }
  
  public boolean hasMtu() {
    return this.mtu != null;
  }
  
  public Boolean getUseExternalOpenvswitch() {
    return this.useExternalOpenvswitch;
  }
  
  public A withUseExternalOpenvswitch(Boolean useExternalOpenvswitch) {
    this.useExternalOpenvswitch = useExternalOpenvswitch;
    return (A) this;
  }
  
  public boolean hasUseExternalOpenvswitch() {
    return this.useExternalOpenvswitch != null;
  }
  
  public Long getVxlanPort() {
    return this.vxlanPort;
  }
  
  public A withVxlanPort(Long vxlanPort) {
    this.vxlanPort = vxlanPort;
    return (A) this;
  }
  
  public boolean hasVxlanPort() {
    return this.vxlanPort != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftSDNConfigFluent that = (OpenShiftSDNConfigFluent) o;
    if (!java.util.Objects.equals(enableUnidling, that.enableUnidling)) return false;
    if (!java.util.Objects.equals(mode, that.mode)) return false;
    if (!java.util.Objects.equals(mtu, that.mtu)) return false;
    if (!java.util.Objects.equals(useExternalOpenvswitch, that.useExternalOpenvswitch)) return false;
    if (!java.util.Objects.equals(vxlanPort, that.vxlanPort)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(enableUnidling,  mode,  mtu,  useExternalOpenvswitch,  vxlanPort,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enableUnidling != null) { sb.append("enableUnidling:"); sb.append(enableUnidling + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (mtu != null) { sb.append("mtu:"); sb.append(mtu + ","); }
    if (useExternalOpenvswitch != null) { sb.append("useExternalOpenvswitch:"); sb.append(useExternalOpenvswitch + ","); }
    if (vxlanPort != null) { sb.append("vxlanPort:"); sb.append(vxlanPort + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withEnableUnidling() {
    return withEnableUnidling(true);
  }
  
  public A withUseExternalOpenvswitch() {
    return withUseExternalOpenvswitch(true);
  }
  

}
